"use strict";
'use client';
Object.defineProperty(exports, "__esModule", { value: true });
exports.defaultSections = void 0;
const tslib_1 = require("tslib");
const react_1 = require("react");
const useCioClient_1 = tslib_1.__importDefault(require("./useCioClient"));
const useDownShift_1 = tslib_1.__importDefault(require("./useDownShift"));
const usePrevious_1 = tslib_1.__importDefault(require("./usePrevious"));
const helpers_1 = require("../utils/helpers");
const format_1 = require("../utils/format");
const tracking_1 = require("../utils/tracking");
const features_1 = require("../utils/features");
const useConsoleErrors_1 = tslib_1.__importDefault(require("./useConsoleErrors"));
const useSections_1 = tslib_1.__importDefault(require("./useSections"));
const useRecommendationsObserver_1 = tslib_1.__importDefault(require("./useRecommendationsObserver"));
const typeGuards_1 = require("../typeGuards");
const useNormalizedProps_1 = tslib_1.__importDefault(require("./useNormalizedProps"));
const useCustomBlur_1 = tslib_1.__importDefault(require("./useCustomBlur"));
exports.defaultSections = [
    {
        indexSectionName: 'Search Suggestions',
        type: 'autocomplete',
    },
    {
        indexSectionName: 'Products',
        type: 'autocomplete',
    },
];
const useCioAutocomplete = (options) => {
    const { sections, zeroStateSections, cioJsClientOptions, advancedParameters } = (0, useNormalizedProps_1.default)(options);
    const { onSubmit, onChange, openOnFocus, apiKey, cioJsClient, placeholder = 'What can we help you find today?', autocompleteClassName = 'cio-autocomplete', defaultInput, getSearchResultsUrl } = options, rest = tslib_1.__rest(options, ["onSubmit", "onChange", "openOnFocus", "apiKey", "cioJsClient", "placeholder", "autocompleteClassName", "defaultInput", "getSearchResultsUrl"]);
    const [query, setQuery] = (0, react_1.useState)(defaultInput || '');
    const previousQuery = (0, usePrevious_1.default)(query);
    const cioClient = (0, useCioClient_1.default)({ apiKey, cioJsClient, cioJsClientOptions });
    // Get autocomplete sections (autocomplete + recommendations + custom)
    const { fetchRecommendationResults, activeSections, activeSectionsWithData, zeroStateActiveSections, request, totalNumResultsPerSection, } = (0, useSections_1.default)(query, cioClient, sections, zeroStateSections, advancedParameters);
    const features = (0, react_1.useMemo)(() => (0, features_1.getFeatures)(request), [request]);
    // Get dropdown items array from active sections (autocomplete + recommendations + custom)
    const items = (0, react_1.useMemo)(() => (0, helpers_1.getItemsForActiveSections)(activeSectionsWithData), [activeSectionsWithData]);
    const { isOpen, getMenuProps, getLabelProps, openMenu, closeMenu, highlightedIndex, getInputProps, getItemProps: getItemPropsDownShift, } = (0, useDownShift_1.default)(Object.assign({ setQuery,
        items,
        onSubmit,
        cioClient,
        previousQuery }, rest));
    (0, useCustomBlur_1.default)(isOpen, closeMenu, autocompleteClassName);
    // Log console errors
    (0, useConsoleErrors_1.default)(sections, activeSections);
    // Track recommendation view
    (0, useRecommendationsObserver_1.default)(isOpen, activeSectionsWithData, cioClient, tracking_1.trackRecommendationView);
    return {
        query,
        sections: activeSectionsWithData,
        totalNumResultsPerSection,
        request,
        featureToggles: features,
        isOpen,
        getMenuProps: () => (Object.assign(Object.assign({}, getMenuProps()), { className: 'cio-results', 'data-testid': 'cio-results', 'data-cnstrc-autosuggest': '' })),
        getLabelProps,
        openMenu,
        closeMenu,
        getItemProps: (item) => {
            var _a;
            const { index, sectionId } = (0, helpers_1.getItemPosition)({ item, items });
            const sectionItemTestId = `cio-item-${sectionId === null || sectionId === void 0 ? void 0 : sectionId.replace(' ', '')}`;
            return Object.assign(Object.assign({}, getItemPropsDownShift({ item, index })), { 
                // @deprecated `sectionItemTestId` will be removed as a className in the next major version
                className: `cio-item ${sectionItemTestId}`, 'data-testid': sectionItemTestId, 'data-cnstrc-item-section': item.section, 'data-cnstrc-item-group': item.groupId, 'data-cnstrc-item-name': item.value, 'data-cnstrc-item-id': (_a = item.data) === null || _a === void 0 ? void 0 : _a.id });
        },
        getInputProps: () => (Object.assign(Object.assign({}, getInputProps({
            onChange: (e) => {
                setQuery(e.target.value);
                if (onChange) {
                    onChange(e.target.value);
                }
            },
        })), { value: query, onFocus: () => {
                var _a;
                if (options.onFocus) {
                    options.onFocus();
                }
                if (zeroStateActiveSections &&
                    openOnFocus !== false &&
                    features.featureDisplayZeroStateRecommendations) {
                    openMenu();
                }
                if (query === null || query === void 0 ? void 0 : query.length) {
                    openMenu();
                }
                try {
                    if (advancedParameters === null || advancedParameters === void 0 ? void 0 : advancedParameters.fetchZeroStateOnFocus) {
                        fetchRecommendationResults();
                    }
                    (_a = cioClient === null || cioClient === void 0 ? void 0 : cioClient.tracker) === null || _a === void 0 ? void 0 : _a.trackInputFocus();
                }
                catch (error) {
                    // eslint-disable-next-line no-console
                    console.log(error);
                }
            }, className: 'cio-input', 'data-testid': 'cio-input', 'data-cnstrc-search-input': '', placeholder, onKeyDownCapture: ({ code, key, nativeEvent }) => {
                const isEnter = code === 'Enter' || key === 'Enter';
                const isHome = code === 'Home' || key === 'Home';
                const isEnd = code === 'End' || key === 'End';
                const isUserInput = highlightedIndex < 0;
                if (isOpen && isEnter && isUserInput && (query === null || query === void 0 ? void 0 : query.length)) {
                    if (onSubmit) {
                        onSubmit({ query });
                    }
                    try {
                        (0, tracking_1.trackSearchSubmit)(cioClient, query, { originalQuery: query });
                    }
                    catch (error) {
                        // eslint-disable-next-line no-console
                        console.log(error);
                    }
                }
                if (isHome || isEnd) {
                    // eslint-disable-next-line no-param-reassign
                    nativeEvent.preventDownshiftDefault = true;
                }
            } })),
        getFormProps: () => ({
            onSubmit: (event) => {
                event.preventDefault();
                if (onSubmit) {
                    onSubmit({ query });
                }
                try {
                    (0, tracking_1.trackSearchSubmit)(cioClient, query, { originalQuery: query });
                }
                catch (error) {
                    // eslint-disable-next-line no-console
                    console.log(error);
                }
                return { query };
            },
            className: 'cio-form',
            'data-testid': 'cio-form',
            'data-cnstrc-search-form': '',
        }),
        getSectionProps: (section) => {
            var _a, _b;
            // @deprecated ClassNames derived from this fn will be removed in the next major version
            const getDeprecatedClassNames = () => {
                const { type } = section;
                let sectionTitle;
                const indexSectionName = type !== 'custom' && section.indexSectionName
                    ? (0, format_1.toKebabCase)(section.indexSectionName)
                    : '';
                switch (type) {
                    case 'recommendations':
                        sectionTitle = section.podId;
                        break;
                    case 'autocomplete':
                        sectionTitle = section.displayName || section.indexSectionName;
                        break;
                    case 'custom':
                        sectionTitle = section.displayName;
                        break;
                    default:
                        sectionTitle = section.displayName || section.indexSectionName;
                        break;
                }
                return `${sectionTitle} ${indexSectionName}`;
            };
            // Always add the indexSectionName (defaults to Products) as a class to the section container for the styles
            // Even if the section is a recommendation pod, if the results are "Products" or "Search Suggestions"
            // ... they should be styled accordingly
            const sectionListingType = (0, typeGuards_1.isCustomSection)(section)
                ? 'custom'
                : (0, format_1.toKebabCase)(section.indexSectionName || ((_a = section.data[0]) === null || _a === void 0 ? void 0 : _a.section) || 'Products');
            const attributes = {
                className: `cio-section cio-section-${sectionListingType} ${getDeprecatedClassNames()}`,
                ref: section.ref,
                role: 'none',
                'data-cnstrc-section': (_b = section.data[0]) === null || _b === void 0 ? void 0 : _b.section,
            };
            if ((0, typeGuards_1.isCustomSection)(section)) {
                attributes['data-cnstrc-custom-section'] = true;
                attributes['data-cnstrc-custom-section-name'] = section.displayName;
            }
            // Add data attributes for recommendations
            if ((0, typeGuards_1.isRecommendationsSection)(section)) {
                attributes['data-cnstrc-recommendations'] = true;
                attributes['data-cnstrc-recommendations-pod-id'] = section.podId;
            }
            return attributes;
        },
        setQuery,
        cioClient,
        autocompleteClassName,
        selectedItem: items[highlightedIndex],
        advancedParameters,
        getSearchResultsUrl,
    };
};
exports.default = useCioAutocomplete;
