"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = require("react");
const useDebounce_1 = tslib_1.__importDefault(require("./useDebounce"));
const transformResponse = (response, options) => {
    const { numTermsWithGroupSuggestions, numGroupsSuggestedPerTerm } = options;
    const newSectionsData = {};
    Object.keys((response === null || response === void 0 ? void 0 : response.sections) || {}).forEach((section) => {
        newSectionsData[section] = [];
        const sectionItems = response.sections[section].map((item) => {
            var _a;
            return (Object.assign(Object.assign({}, item), { id: (_a = item === null || item === void 0 ? void 0 : item.data) === null || _a === void 0 ? void 0 : _a.id, section }));
        });
        sectionItems.forEach((item, itemIndex) => {
            var _a, _b, _c;
            (_a = newSectionsData[section]) === null || _a === void 0 ? void 0 : _a.push(item);
            if (section === 'Search Suggestions' &&
                ((_c = (_b = item === null || item === void 0 ? void 0 : item.data) === null || _b === void 0 ? void 0 : _b.groups) === null || _c === void 0 ? void 0 : _c.length) &&
                itemIndex < numTermsWithGroupSuggestions) {
                item.data.groups.forEach((group, groupIndex) => {
                    var _a, _b;
                    if (groupIndex < numGroupsSuggestedPerTerm) {
                        const inGroupSearchSuggestion = Object.assign(Object.assign({}, item), { id: `${(_a = item.data) === null || _a === void 0 ? void 0 : _a.id}_${group.group_id}`, groupName: group.display_name, groupId: group.group_id });
                        (_b = newSectionsData[section]) === null || _b === void 0 ? void 0 : _b.push(inGroupSearchSuggestion);
                    }
                });
            }
        });
    });
    return {
        sectionsData: newSectionsData,
        request: response === null || response === void 0 ? void 0 : response.request,
        totalNumResultsPerSection: response === null || response === void 0 ? void 0 : response.total_num_results_per_section,
    };
};
const useDebouncedFetchSection = (query, cioClient, autocompleteSections, advancedParameters) => {
    // This says sectionsData but it also contain request information
    const [sectionsData, setSectionsData] = (0, react_1.useState)({
        sectionsData: {},
        request: {},
        totalNumResultsPerSection: {},
    });
    const debouncedSearchTerm = (0, useDebounce_1.default)(query, advancedParameters === null || advancedParameters === void 0 ? void 0 : advancedParameters.debounce);
    const { numTermsWithGroupSuggestions = 0, numGroupsSuggestedPerTerm = 0 } = advancedParameters || {};
    const autocompleteParameters = (0, react_1.useMemo)(() => {
        const decoratedParameters = Object.assign({}, advancedParameters);
        // eslint-disable-next-line no-param-reassign
        decoratedParameters === null || decoratedParameters === void 0 ? true : delete decoratedParameters.debounce;
        if (autocompleteSections) {
            decoratedParameters.resultsPerSection = autocompleteSections.reduce((acc, sectionConfig) => (Object.assign(Object.assign({}, acc), { [sectionConfig.indexSectionName]: (sectionConfig === null || sectionConfig === void 0 ? void 0 : sectionConfig.numResults) || 8 })), {});
        }
        return decoratedParameters;
    }, [autocompleteSections, advancedParameters]);
    (0, react_1.useEffect)(() => {
        (() => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
            const trimmedTerm = debouncedSearchTerm.trim();
            // Do not send a request if the encoded term is longer than 199 characters
            if (trimmedTerm && encodeURIComponent(trimmedTerm).length < 200) {
                try {
                    const response = yield (cioClient === null || cioClient === void 0 ? void 0 : cioClient.autocomplete.getAutocompleteResults(debouncedSearchTerm, autocompleteParameters));
                    if (response) {
                        const newSectionsData = transformResponse(response, {
                            numTermsWithGroupSuggestions,
                            numGroupsSuggestedPerTerm,
                        });
                        setSectionsData(newSectionsData);
                    }
                }
                catch (error) {
                    // eslint-disable-next-line no-console
                    console.log(error);
                }
            }
            else if (!debouncedSearchTerm) {
                setSectionsData({ sectionsData: {}, request: {}, totalNumResultsPerSection: {} });
            }
        }))();
    }, [
        debouncedSearchTerm,
        cioClient,
        numTermsWithGroupSuggestions,
        numGroupsSuggestedPerTerm,
        autocompleteParameters,
    ]);
    return sectionsData;
};
exports.default = useDebouncedFetchSection;
