"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.defaultSections = void 0;
/* eslint-disable react-hooks/exhaustive-deps */
const react_1 = require("react");
const typeGuards_1 = require("../typeGuards");
exports.defaultSections = [
    {
        indexSectionName: 'Search Suggestions',
        type: 'autocomplete',
    },
    {
        indexSectionName: 'Products',
        type: 'autocomplete',
    },
];
const convertLegacyParametersAndAddDefaults = (sections) => sections.map((config) => {
    if ((0, typeGuards_1.isRecommendationsSection)(config)) {
        if (config.identifier && !config.podId) {
            return Object.assign(Object.assign({}, config), { podId: config.identifier });
        }
        if (!config.indexSectionName) {
            return Object.assign(Object.assign({}, config), { indexSectionName: 'Products' });
        }
    }
    if ((0, typeGuards_1.isAutocompleteSection)(config)) {
        if (config.identifier && !config.indexSectionName) {
            return Object.assign(Object.assign({}, config), { indexSectionName: config.identifier });
        }
    }
    return config;
});
const normalizeSections = (sections) => {
    if (sections) {
        return convertLegacyParametersAndAddDefaults(sections);
    }
    return sections;
};
// Normalize and Memoize Objects to prevent infinite rerenders if users pass object literals to useCioAutocomplete
const useNormalizedProps = (options) => {
    const { sections = exports.defaultSections, zeroStateSections, cioJsClientOptions, advancedParameters, } = options;
    const sectionsMemoized = (0, react_1.useMemo)(() => normalizeSections(sections), [JSON.stringify(sections)]);
    const zeroStateSectionsMemoized = (0, react_1.useMemo)(() => normalizeSections(zeroStateSections), [JSON.stringify(zeroStateSections)]);
    const cioJsClientOptionsMemoized = (0, react_1.useMemo)(() => cioJsClientOptions, [JSON.stringify(cioJsClientOptions)]);
    const advancedParametersMemoized = (0, react_1.useMemo)(() => advancedParameters, [JSON.stringify(advancedParameters)]);
    return {
        sections: sectionsMemoized,
        zeroStateSections: zeroStateSectionsMemoized,
        cioJsClientOptions: cioJsClientOptionsMemoized,
        advancedParameters: advancedParametersMemoized,
    };
};
exports.default = useNormalizedProps;
