"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
/* eslint-disable max-params */
const react_1 = require("react");
const useActiveSections_1 = tslib_1.__importDefault(require("./useActiveSections"));
const useSectionsResults_1 = tslib_1.__importDefault(require("./useSectionsResults"));
const useActiveSectionsWithData_1 = tslib_1.__importDefault(require("./useActiveSectionsWithData"));
const useRemoveSections_1 = tslib_1.__importDefault(require("./useRemoveSections"));
function useSections(query, cioClient, sections, zeroStateSections, advancedParameters) {
    const [podsData, setPodsData] = (0, react_1.useState)({});
    // Get Active Sections defined by configuration object
    const { activeSections, showZeroStateSections, setActiveSections } = (0, useActiveSections_1.default)(query, sections, podsData, zeroStateSections);
    // create refs for active sections
    const sectionsRefs = (0, react_1.useRef)(activeSections.map(() => (0, react_1.createRef)()));
    // Get API results for each active section
    const { recommendations, autocomplete } = (0, useSectionsResults_1.default)(query, cioClient, activeSections, advancedParameters);
    // Access the Pods Data from the Recommendations response to update Active Sections configuration
    (0, react_1.useEffect)(() => {
        if (!recommendations.podsData) {
            setPodsData(recommendations.podsData);
        }
    }, [recommendations.podsData]);
    (0, useRemoveSections_1.default)(sections, podsData, setActiveSections, showZeroStateSections, zeroStateSections);
    // Combine recommendations and autocomplete results in sectionsResults
    const sectionsResults = (0, react_1.useMemo)(() => (Object.assign(Object.assign({}, autocomplete.results), recommendations.results)), [autocomplete.results, recommendations.results]);
    // Return current active sections populated with data from the API response sectionsResults
    const activeSectionsWithData = (0, useActiveSectionsWithData_1.default)(sectionsResults, activeSections, sectionsRefs, query, recommendations.podsData);
    return {
        fetchRecommendationResults: recommendations.fetchRecommendationResults,
        activeSections,
        activeSectionsWithData,
        zeroStateActiveSections: showZeroStateSections,
        request: autocomplete.request,
        totalNumResultsPerSection: autocomplete.totalNumResultsPerSection,
    };
}
exports.default = useSections;
