"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.storeRecentAction = exports.getLastAction = exports.getRecentActions = exports.storeRecentSearch = exports.getRecentSearches = exports.cleanTerm = exports.CONSTANTS = void 0;
// eslint-disable-next-line import/no-cycle
const storage_1 = require("./storage");
exports.CONSTANTS = {
    SEARCH_SUBMIT: 'SEARCH_SUBMIT',
    RECENT_ACTIONS_STORAGE_KEY: {
        scope: 'session',
        key: '_constructorio_recent_actions',
    },
    RECENT_SEARCHES_STORAGE_KEY: {
        scope: 'local',
        key: '_constructorio_recent_searches',
    },
    SEARCH_TERM_STORAGE_KEY: {
        scope: 'session',
        key: '_constructorio_search_term',
    },
    RECENT_SEARCHES_STORAGE_COUNT: 100,
    RECENT_ACTION_STORAGE_COUNT: 5,
};
/*
 * Use the text content of the resulting HTML node(s) created from the
 * term
 */
const cleanTerm = (term) => {
    // Remove all scripts and image tags from term
    const tmp = document.implementation.createHTMLDocument('');
    tmp.body.innerHTML = term;
    const scriptsAndImages = [...tmp.body.querySelectorAll('script, img')];
    scriptsAndImages.forEach((el) => {
        tmp.body.removeChild(el);
    });
    const nodes = tmp.body.childNodes;
    const texts = [...nodes].map((node) => node.innerText || node.textContent);
    return texts.join('');
};
exports.cleanTerm = cleanTerm;
/*
 * Returns a list of recent searches
 */
const getRecentSearches = () => {
    const recentSearches = (0, storage_1.storageGetArray)(exports.CONSTANTS.RECENT_SEARCHES_STORAGE_KEY) || [];
    // upgrade the array to store timestamps if it isn't already
    recentSearches.forEach((item, i) => {
        if (typeof item === 'string') {
            recentSearches[i] = {
                term: item,
                ts: Date.now(),
            };
        }
    });
    return recentSearches;
};
exports.getRecentSearches = getRecentSearches;
/*
 * Stores a recent search
 */
const storeRecentSearch = (term, suggestionData) => {
    const cleanedTerm = (0, exports.cleanTerm)(term.trim());
    let recentSearches = (0, exports.getRecentSearches)();
    if (cleanedTerm.length > 0) {
        // this ensures it goes onto the end of the array, and only there
        recentSearches = recentSearches.filter((item) => { var _a; return ((_a = item.term) === null || _a === void 0 ? void 0 : _a.toUpperCase()) !== cleanedTerm.toUpperCase(); });
        // reset the section to the original section if it's present because that's
        // the real section we want to store
        if (suggestionData === null || suggestionData === void 0 ? void 0 : suggestionData.original_section) {
            /* eslint-disable no-param-reassign */
            suggestionData.section = suggestionData.original_section;
            delete suggestionData.original_section;
            delete suggestionData.is_meta_section;
            /* eslint-enable no-param-reassign */
        }
        recentSearches.push({
            term: cleanedTerm,
            ts: Date.now(),
            data: suggestionData,
        });
        while (recentSearches.length > exports.CONSTANTS.RECENT_SEARCHES_STORAGE_COUNT) {
            recentSearches.shift();
        }
        (0, storage_1.storageSetItem)(exports.CONSTANTS.RECENT_SEARCHES_STORAGE_KEY, JSON.stringify(recentSearches));
    }
};
exports.storeRecentSearch = storeRecentSearch;
/*
 * Returns a list of recent actions
 */
const getRecentActions = () => (0, storage_1.storageGetArray)(exports.CONSTANTS.RECENT_ACTIONS_STORAGE_KEY) || [];
exports.getRecentActions = getRecentActions;
/*
 * Returns the last action
 */
const getLastAction = () => {
    var _a;
    const recentActions = (0, exports.getRecentActions)();
    if (recentActions && recentActions.length) {
        return (_a = recentActions[recentActions.length - 1]) === null || _a === void 0 ? void 0 : _a.action;
    }
    return null;
};
exports.getLastAction = getLastAction;
/*
 * Stores a recent action
 * Currently only storing search submits, search loads and browse loads
 */
const storeRecentAction = (action) => {
    let recentActions = (0, exports.getRecentActions)();
    if (action) {
        // Only add non-consecutive actions
        if ((0, exports.getLastAction)() !== action) {
            recentActions.push({
                action,
                ts: Date.now(),
            });
        }
        if (recentActions.length > exports.CONSTANTS.RECENT_ACTION_STORAGE_COUNT) {
            recentActions = recentActions.slice(-1 * exports.CONSTANTS.RECENT_ACTION_STORAGE_COUNT);
        }
        (0, storage_1.storageSetItem)(exports.CONSTANTS.RECENT_ACTIONS_STORAGE_KEY, JSON.stringify(recentActions));
    }
};
exports.storeRecentAction = storeRecentAction;
