"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getFeatures = void 0;
const storage_1 = require("./storage");
const AUTOSUGGEST_CUSTOM_UI_VARIANTS = [
    'custom_autosuggest_ui_result_count',
    'custom_autosuggest_ui_image',
    'custom_autosuggest_ui_image_result_count',
    'custom_autosuggest_ui_disable_recommendations_in_zero_state',
];
const AUTOSUGGEST_CUSTOM_UI_STORAGE_KEY = {
    scope: 'session',
    key: '_constructorio_custom_autosuggest_ui',
};
const isCustomAutosuggestUiVariant = (variant) => AUTOSUGGEST_CUSTOM_UI_VARIANTS.includes(variant);
const getCustomUiVariantFromStorage = () => {
    const item = (0, storage_1.storageGetItem)(AUTOSUGGEST_CUSTOM_UI_STORAGE_KEY);
    return item && isCustomAutosuggestUiVariant(item) ? item : null;
};
// eslint-disable-next-line import/prefer-default-export
function getFeatures(request) {
    var _a, _b, _c, _d;
    let featureDisplaySearchSuggestionImages = false;
    let featureDisplaySearchSuggestionResultCounts = false;
    let featureDisplayZeroStateRecommendations = true;
    let customAutosuggestUi = null;
    if (((_a = request === null || request === void 0 ? void 0 : request.features) === null || _a === void 0 ? void 0 : _a.custom_autosuggest_ui) === true &&
        isCustomAutosuggestUiVariant((_b = request === null || request === void 0 ? void 0 : request.feature_variants) === null || _b === void 0 ? void 0 : _b.custom_autosuggest_ui)) {
        customAutosuggestUi = (_d = (_c = request === null || request === void 0 ? void 0 : request.feature_variants) === null || _c === void 0 ? void 0 : _c.custom_autosuggest_ui) !== null && _d !== void 0 ? _d : null;
    }
    // If a variant is set in the session storage, override the request variant
    const customVariantFromStorage = getCustomUiVariantFromStorage();
    if (customVariantFromStorage) {
        customAutosuggestUi = customVariantFromStorage;
    }
    if (customAutosuggestUi !== null) {
        switch (customAutosuggestUi) {
            case 'custom_autosuggest_ui_result_count':
                featureDisplaySearchSuggestionResultCounts = true;
                break;
            case 'custom_autosuggest_ui_image':
                featureDisplaySearchSuggestionImages = true;
                break;
            case 'custom_autosuggest_ui_image_result_count':
                featureDisplaySearchSuggestionImages = true;
                featureDisplaySearchSuggestionResultCounts = true;
                break;
            case 'custom_autosuggest_ui_disable_recommendations_in_zero_state':
                featureDisplayZeroStateRecommendations = false;
                break;
            default:
                break;
        }
    }
    return {
        featureDisplaySearchSuggestionImages,
        featureDisplaySearchSuggestionResultCounts,
        featureDisplayZeroStateRecommendations,
    };
}
exports.getFeatures = getFeatures;
