"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.stringifyWithDefaults = exports.toKebabCase = exports.camelToStartCase = void 0;
const helpers_1 = require("./helpers");
const camelToStartCase = (camelCaseString) => camelCaseString
    // insert a space between lower & upper
    .replace(/([a-z])([A-Z])/g, '$1 $2')
    // space before last upper in a sequence followed by lower
    .replace(/\b([A-Z]+)([A-Z])([a-z])/, '$1 $2$3')
    // uppercase the first letter
    .replace(/([a-zA-Z])/, (str) => str.toUpperCase());
exports.camelToStartCase = camelToStartCase;
const toKebabCase = (str) => str
    .replace(/([A-Z])([A-Z][a-z])/g, '$1-$2')
    .replace(/([a-z])([A-Z])/g, '$1-$2')
    .replace(/[\s_]+/g, '-')
    .toLowerCase();
exports.toKebabCase = toKebabCase;
const stringifyWithDefaults = (obj) => {
    // Stringify non-function values normally. Add a template block for functions to be replaced later
    let res = JSON.stringify(obj, (key, value) => (value instanceof Function ? `${key}_CODE` : value), '  ');
    // Replace template blocks with function strings
    Array.from(res.matchAll(/"(\w*)_CODE"/g)).forEach((match) => {
        const [codePlaceholder, key] = match;
        const functionString = helpers_1.functionStrings[key];
        if (functionString) {
            res = res.replaceAll(codePlaceholder, functionString);
        }
        else {
            console.error(`Function string for ${key} not found.`); // eslint-disable-line
        }
    });
    return res;
};
exports.stringifyWithDefaults = stringifyWithDefaults;
