"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.logger = exports.translate = exports.getItemsForActiveSections = exports.escapeRegExp = exports.getActiveSectionsWithData = exports.getCioClient = exports.disableStoryActions = exports.functionStrings = exports.getStoryParams = exports.sleep = exports.clearConstructorRequests = exports.getItemPosition = void 0;
const tslib_1 = require("tslib");
const constructorio_client_javascript_1 = tslib_1.__importDefault(require("@constructor-io/constructorio-client-javascript"));
const version_1 = tslib_1.__importDefault(require("../version"));
const getItemPosition = ({ item, items }) => {
    var _a;
    const index = items.findIndex((itemInFlatList) => (itemInFlatList === null || itemInFlatList === void 0 ? void 0 : itemInFlatList.id) === (item === null || item === void 0 ? void 0 : item.id));
    const sectionId = (_a = items[index]) === null || _a === void 0 ? void 0 : _a.section;
    return { sectionId, index };
};
exports.getItemPosition = getItemPosition;
function clearConstructorRequests() {
    var _a;
    // eslint-disable-next-line
    if ((_a = window.localStorage) === null || _a === void 0 ? void 0 : _a._constructorio_requests) {
        window.localStorage.removeItem('_constructorio_requests');
    }
}
exports.clearConstructorRequests = clearConstructorRequests;
// Function to emulate pausing between interactions
function sleep(ms) {
    // eslint-disable-next-line
    return new Promise((resolve) => setTimeout(resolve, ms));
}
exports.sleep = sleep;
// More on Story layout: https://storybook.js.org/docs/react/configure/story-layout
const getStoryParams = (storyCode, templateCode, importCode) => {
    const code = `
${importCode}
${storyCode}
${templateCode}
`;
    return {
        docs: {
            source: {
                code,
                language: 'jsx',
                format: true,
                type: 'code',
            },
        },
    };
};
exports.getStoryParams = getStoryParams;
exports.functionStrings = {
    onSubmit: `(submitEvent) => console.dir(submitEvent)`,
    renderItem: `({ item, query, getItemProps }) => (
                      <div {...getItemProps(item)}>
                          <a href={item.data?.url}>
                            <h3>{item.value}</h3>
                            <img src={item.data?.image_url} alt={item.value} />
                          </a>
                          <p>{item.data?.price}</p>
                      </div>
                    )`,
};
const disableStoryActions = (story) => {
    // eslint-disable-next-line
    story.parameters.actions = { argTypesRegex: null };
};
exports.disableStoryActions = disableStoryActions;
const getCioClient = (apiKey, cioJsClientOptions) => {
    if (apiKey && typeof window !== 'undefined') {
        const cioClient = new constructorio_client_javascript_1.default(Object.assign({ apiKey, sendTrackingEvents: true, version: `cio-ui-autocomplete-${version_1.default}` }, cioJsClientOptions));
        // eslint-disable-next-line no-console
        cioClient.tracker.on('error', (error) => console.error(error));
        return cioClient;
    }
    return null;
};
exports.getCioClient = getCioClient;
const getActiveSectionsWithData = (activeSections, sectionsResults, sectionsRefs, podsData) => {
    const activeSectionsWithData = [];
    const getSectionData = (sectionConfig) => {
        const { type } = sectionConfig;
        let sectionData;
        switch (type) {
            case 'recommendations':
                sectionData = sectionsResults[sectionConfig.podId];
                break;
            case 'custom':
                // Copy id from data to the top level
                sectionData = sectionConfig.data.map((item) => {
                    var _a;
                    return (Object.assign(Object.assign({}, item), { id: (item === null || item === void 0 ? void 0 : item.id) || ((_a = item === null || item === void 0 ? void 0 : item.data) === null || _a === void 0 ? void 0 : _a.id) }));
                });
                break;
            default:
                // Autocomplete
                sectionData = sectionsResults[sectionConfig.indexSectionName];
        }
        return sectionData;
    };
    activeSections === null || activeSections === void 0 ? void 0 : activeSections.forEach((sectionConfig, index) => {
        const sectionData = getSectionData(sectionConfig);
        if (Array.isArray(sectionData)) {
            const section = Object.assign(Object.assign({}, sectionConfig), { data: sectionData });
            if (sectionConfig.type === 'recommendations') {
                section.displayName =
                    sectionConfig.displayName || podsData[sectionConfig.podId].displayName;
            }
            // If ref passed as part of `SectionConfiguration`, use it.
            // Otherwise, use the ref from our library generated refs array
            const userDefinedSectionRef = sectionConfig.ref;
            const libraryGeneratedSectionRef = sectionsRefs.current[index];
            section.ref = userDefinedSectionRef || libraryGeneratedSectionRef;
            activeSectionsWithData.push(section);
        }
    });
    return activeSectionsWithData;
};
exports.getActiveSectionsWithData = getActiveSectionsWithData;
const escapeRegExp = (string) => string.replace(/[.*+?^${}()|[\]\\]/g, '\\$&');
exports.escapeRegExp = escapeRegExp;
const getItemsForActiveSections = (activeSectionsWithData) => {
    const items = [];
    activeSectionsWithData === null || activeSectionsWithData === void 0 ? void 0 : activeSectionsWithData.forEach((config) => {
        if (config === null || config === void 0 ? void 0 : config.data) {
            items.push(...config.data);
        }
    });
    return items;
};
exports.getItemsForActiveSections = getItemsForActiveSections;
const translate = (word, translations) => {
    const localTranslations = {
        in: 'in',
        'show all results': 'show all results',
    };
    if (translations)
        return translations[word];
    return localTranslations[word] || word;
};
exports.translate = translate;
const logger = (error) => {
    var _a;
    try {
        if (typeof process !== 'undefined' && ((_a = process === null || process === void 0 ? void 0 : process.env) === null || _a === void 0 ? void 0 : _a.LOGGER)) {
            // eslint-disable-next-line no-console
            console.log(error);
        }
    }
    catch (e) {
        // process variable is not available and logger should not be active
    }
};
exports.logger = logger;
