"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.storageRemoveItem = exports.storageSetItem = exports.storageGetArray = exports.storageGetItem = exports.getStorageEngine = void 0;
const helpers_1 = require("./helpers");
// Return storage engine based on scope
const getStorageEngine = (scope) => {
    if (scope === 'local') {
        return localStorage;
    }
    return sessionStorage;
};
exports.getStorageEngine = getStorageEngine;
// Retrieves item from storage for key
const storageGetItem = (key) => {
    try {
        const storageEngine = (0, exports.getStorageEngine)(key.scope);
        return storageEngine.getItem(key.key);
    }
    catch (e) {
        (0, helpers_1.logger)(`storageGetItem error: ${e}`);
        return null;
    }
};
exports.storageGetItem = storageGetItem;
// Retrieve array from storage
const storageGetArray = (key) => {
    const item = (0, exports.storageGetItem)(key);
    if (item) {
        try {
            const array = JSON.parse(item);
            return array;
        }
        catch (e) {
            (0, helpers_1.logger)(`storageGetArray error: ${e}`);
        }
    }
    return null;
};
exports.storageGetArray = storageGetArray;
// Set item in storage
const storageSetItem = (key, value) => {
    try {
        const storageEngine = (0, exports.getStorageEngine)(key.scope);
        return storageEngine.setItem(key.key, value);
    }
    catch (e) {
        (0, helpers_1.logger)(`storageSetItem error: ${e}`);
        return null;
    }
};
exports.storageSetItem = storageSetItem;
// Remove item in storage
const storageRemoveItem = (key) => {
    try {
        const storageEngine = (0, exports.getStorageEngine)(key.scope);
        return storageEngine.removeItem(key.key);
    }
    catch (e) {
        (0, helpers_1.logger)(`storageRemoveItem error: ${e}`);
        return null;
    }
};
exports.storageRemoveItem = storageRemoveItem;
