import { Nullable } from '@constructor-io/constructorio-client-javascript/lib/types';
import ConstructorIO from '@constructor-io/constructorio-client-javascript';
import { Section } from '../types';
/**
 * Custom hook that observes the visibility of recommendation sections and calls trackRecommendationView event.
 * This is done by using the IntersectionObserver API to observe the visibility of each recommendation section.
 * That is done by passing the ref of each recommendation section to the IntersectionObserver.
 * The refs are either passed as a prop in `SectionConfiguration` or created by the library by default.
 * Either way the refs are stored in the sections array.
 *
 * @param menuIsOpen - A boolean indicating whether the menu is open.
 * @param sections - An array of sections to observe.
 * @param constructorIO - An instance of the ConstructorIO client.
 * @param trackRecommendationView - A callback function to track the recommendation view event.
 */
declare function useRecommendationsObserver(menuIsOpen: boolean, sections: Section[], constructorIO: Nullable<ConstructorIO>, trackRecommendationView: (target: HTMLElement, sections: Section[], constructorIO: Nullable<ConstructorIO>) => void): void;
export default useRecommendationsObserver;
